# Tutorials

[![image](https://studiolab.sagemaker.aws/studiolab.svg)](https://studiolab.sagemaker.aws/import/github/opengeoshub/vgrid/blob/master/docs/notebooks/00_h3.ipynb)
[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/opengeoshub/vgrid/blob/master)
[![image](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/opengeoshub/vgrid/HEAD)


## Tutorials

1. Introducing the vgrid Python package for interactive mapping ([video](https://youtu.be/-UPt7x3Gn60) | [gif](https://i.imgur.com/2pRxunR.gif) | [notebook](https://vgrid.org/notebooks/01_vgrid_intro))
2. Using basemaps in vgrid ([video](https://youtu.be/uylpjbDZesY) | [gif](https://youtu.be/-lOo-vxjrDM) | [notebook](https://vgrid.org/notebooks/02_using_basemaps))
3. Using Cloud Optimized GeoTIFF (COG) and SpatioTemporal Asset Catalog (STAC) ([notebook](https://vgrid.org/notebooks/03_cog_stac))
4. Creating a virtual mosaic of Cloud Optimized GeoTIFFs (COG) ([notebook](https://vgrid.org/notebooks/04_cog_mosaic))
5. Loading local raster datasets with vgrid ([notebook](https://vgrid.org/notebooks/05_load_raster))
6. Adding custom legends to the map ([notebook](https://vgrid.org/notebooks/06_legend))
7. Adding custom colorbars to the map ([notebook](https://vgrid.org/notebooks/07_colorbar))
8. Using WhiteboxTools with vgrid ([notebook](https://vgrid.org/notebooks/08_whitebox))
9. Converting CSV to points ([notebook](https://vgrid.org/notebooks/09_csv_to_points))
10. Adding local vector data (e.g., shp, geojson, kml) to the map ([notebook](https://vgrid.org/notebooks/10_add_vector))
11. Creating linked maps for visualizing multiple maps simultaneously ([notebook](https://vgrid.org/notebooks/11_linked_maps))
12. Creating a split-panel map with only one line of code ([notebook](https://vgrid.org/notebooks/12_split_map))
13. Adding a GeoPandas GeoDataFrame to the map with a single line of code ([notebook](https://vgrid.org/notebooks/13_geopandas/))
14. Adding data from a PostGIS database to the map ([notebook](https://vgrid.org/notebooks/14_postgis))
15. Downloading OpenStreetMap data with a single line of code ([notebook](https://vgrid.org/notebooks/15_openstreetmap))
16. Using [HERE Map Widget for Jupyter](https://github.com/heremaps/here-map-widget-for-jupyter) as a plotting backend ([notebook](https://vgrid.org/notebooks/16_heremap))
17. Adding vector tile layers to the map ([notebook](https://vgrid.org/notebooks/17_vector_tile_layer))
18. Adding a point layer with popup attributes to the map ([notebook](https://vgrid.org/notebooks/18_point_layer))
19. Saving maps as a html file ([notebook](https://vgrid.org/notebooks/19_map_to_html))
20. Adding Planet global monthly and quarterly mosaic ([notebook](https://vgrid.org/notebooks/20_planet_imagery))
21. Using timeseries inspector with a single click ([notebook](https://vgrid.org/notebooks/21_ts_inspector))
22. Using time slider for visualizing timeseries images ([notebook](https://vgrid.org/notebooks/22_time_slider))
23. Creating colormaps with a single line of code ([notebook](https://vgrid.org/notebooks/23_colormaps))
24. Creating heat map from csv ([notebook](https://vgrid.org/notebooks/24_heatmap))
25. Creating a population heat map with a colorbar and map title ([notebook](https://vgrid.org/notebooks/25_map_title))
26. Creating an interactive map using the kepler.gl plotting backend ([notebook](https://vgrid.org/notebooks/26_kepler_gl))
27. Creating a basemap gallery ([notebook](https://vgrid.org/notebooks/27_basemap_gallery))
28. Publishing maps with a single line of code ([notebook](https://vgrid.org/notebooks/28_publish_map))
29. Using the pydeck plotting backend ([notebook](https://vgrid.org/notebooks/29_pydeck))
30. Using U.S. Census data ([notebook](https://vgrid.org/notebooks/30_census_data))
31. Searching basemaps with xyzservices ([notebook](https://vgrid.org/notebooks/31_search_basemaps))
32. Loading local raster datasets and Cloud Optimized GeoTIFF (COG) ([notebook](https://vgrid.org/notebooks/32_local_tile))
33. Adding image overlay to the map ([notebook](https://vgrid.org/notebooks/33_image_overlay))
34. Adding points from xy data (e.g., CSV, Pandas DataFrame) ([notebook](https://vgrid.org/notebooks/34_add_points_from_xy))
35. Adding circle markers from xy data (e.g., CSV, Pandas DataFrame) ([notebook](https://vgrid.org/notebooks/35_circle_markers))
36. Adding labels to the map ([notebook](https://vgrid.org/notebooks/36_add_labels))
37. Adding Planetary Computer STAC item to the map ([notebook](https://vgrid.org/notebooks/37_planetary_computer))
38. Using the plotly plotting backend ([notebook](https://vgrid.org/notebooks/38_plotly))
39. Getting pixel values using the Inspector tool ([notebook](https://vgrid.org/notebooks/39_inspector_tool))
40. Using the interactive plotly toolbar GUI ([notebook](https://vgrid.org/notebooks/40_plotly_gui))
41. Loading COG/STAC items using the raster GUI ([notebook](https://vgrid.org/notebooks/41_raster_gui))
42. Creating Cloud Optimized GeoTIFF (COG) ([notebook](https://vgrid.org/notebooks/42_create_cog))
43. Searching for locations and features in vector data ([notebook](https://vgrid.org/notebooks/43_search_control))
44. Opening vector data attribute table without coding ([notebook](https://vgrid.org/notebooks/44_attribute_table))
45. Creating vector data interactively without coding ([notebook](https://vgrid.org/notebooks/45_create_vector))
46. Editing existing vector data interactively without coding ([notebook](https://vgrid.org/notebooks/46_edit_vector))
47. Converting numpy array to COG ([notebook](https://vgrid.org/notebooks/47_numpy_to_cog))
48. Visualizing LiDAR data in 3D with only one line of code ([notebook](https://vgrid.org/notebooks/48_lidar))
49. Creating a split-panel map with folium ([notebook](https://vgrid.org/notebooks/49_split_control))
50. Creating a marker cluster with custom icons ([notebook](https://vgrid.org/notebooks/50_marker_cluster))
51. Clipping an image by mask ([notebook](https://vgrid.org/notebooks/51_clip_image))
52. Visualizing NetCDF data ([notebook](https://vgrid.org/notebooks/52_netcdf/))
53. Creating choropleth maps with a variety of classification schemes ([notebook](https://vgrid.org/notebooks/53_choropleth))
54. Plotting elevation data in 3D without only one line of code ([notebook](https://vgrid.org/notebooks/54_plot_raster))
55. LiDAR data analysis and visualization with whitebox and vgrid ([notebook](https://vgrid.org/notebooks/55_lidar))
56. Downloading 10-m National Elevation Dataset (NED) with only one line of code ([notebook](https://vgrid.org/notebooks/56_download_ned))
57. Download data from The National Map ([notebook](https://vgrid.org/notebooks/57_national_map))
58. Creating interactive maps with bokeh ([notebook](https://vgrid.org/notebooks/58_bokeh))
59. Creating legends using vgrid with only one line of code ([notebook](https://vgrid.org/notebooks/59_create_legend))
60. Adding text, images, HTML, and widgets to the map ([notebook](https://vgrid.org/notebooks/60_add_widget))
61. Creating an animated GIF from a vector dataset ([notebook](https://vgrid.org/notebooks/61_vector_to_gif))
62. Adding colorbars to a folium map ([notebook](https://vgrid.org/notebooks/62_folium_colorbar))
63. Using vgrid with ArcGIS Pro ([notebook](https://vgrid.org/notebooks/63_arcgis))
64. Searching open geospatial datasets using STAC API ([notebook](https://vgrid.org/notebooks/64_stac_search))
65. Visualizing raster datasets interactively in SageMaker Studio Lab ([notebook](https://vgrid.org/notebooks/65_sagemaker))
66. Developing interactive web apps with gradio and vgrid ([notebook](https://vgrid.org/notebooks/66_gradio))
67. Visualizing Maxar Open Data with vgrid ([notebook](https://vgrid.org/notebooks/67_maxar_open_data))
68. Searching and visualizing OpenAerialMap imagery with vgrid ([notebook](https://vgrid.org/notebooks/68_openaerialmap))
69. Visualizing Maxar Open Data for the 2023 Turkey-Syria Earthquake ([notebook](https://vgrid.org/notebooks/69_turkey_earthquake))
70. Calculating zonal statistics - summarizing geospatial raster datasets based on vector geometries ([notebook](https://vgrid.org/notebooks/70_zonal_stats))
71. Loading geospatial datasets from an AWS S3 bucket ([notebook](https://vgrid.org/notebooks/71_aws_s3))
72. Creating timelapse animations from satellite imagery timeseries ([notebook](https://vgrid.org/notebooks/72_timelapse))
73. Searching Geospatial Data Interactively with Custom STAC API Endpoints ([notebook](https://vgrid.org/notebooks/73_custom_stac))
74. Downloading maps tiles and converting them to a GeoTIFF file ([notebook](https://vgrid.org/notebooks/74_map_tiles_to_geotiff))
75. Segmenting satellite imagery with the Segment Anything Model ([notebook](https://vgrid.org/notebooks/75_segment_anything))
76. Comparing images with an interactive slider ([notebook](https://vgrid.org/notebooks/76_image_comparison))
77. Splitting a raster dataset into multiple tiles ([notebook](https://vgrid.org/notebooks/77_split_raster))
78. Interactive Extraction and Visualization of AWS Open Geospatial Data ([notebook](https://vgrid.org/notebooks/78_read_raster))
79. Visualizing time series images interactively with a time slider ([notebook](https://vgrid.org/notebooks/79_timeseries))
80. Visualizing solar radiation data from Google Solar API ([notebook](https://vgrid.org/notebooks/80_solar))
81. Downloading Microsoft and Google Building Footprints ([notebook](https://vgrid.org/notebooks/81_buildings))
82. Visualizing PMTiles with vgrid ([notebook](https://vgrid.org/notebooks/82_pmtiles))
83. Visualizing large vector datasets with lonboard ([notebook](https://vgrid.org/notebooks/83_vector_viz))
84. Reading GeoParquet files and visualizing vector data interactively ([notebook](https://vgrid.org/notebooks/84_read_parquet))
85. How to search and download GEDI L4A dataset interactively ([notebook](https://vgrid.org/notebooks/85_gedi))
86. Adding markers to the map ([notebook](https://vgrid.org/notebooks/86_add_markers))
87. Cloud-based geoprocessing with Actinia ([notebook](https://vgrid.org/notebooks/87_actinia))
88. Searching and downloading NASA Earth science data products ([notebook](https://vgrid.org/notebooks/88_nasa_earth_data))
89. Visualizing in-memory raster datasets and image arrays ([notebook](https://vgrid.org/notebooks/89_image_array_viz))
90. Querying pixel values with the interactive pixel inspector ([notebook](https://vgrid.org/notebooks/90_pixel_inspector))
91. Visualizing raster data interactively ([notebook](https://vgrid.org/notebooks/91_raster_viz_gui))
92. Creating 3D maps with the MapLibre mapping backend ([notebook](https://vgrid.org/notebooks/92_maplibre))
93. Visualizing PMTiles with vgrid and MapLibre ([notebook](https://vgrid.org/notebooks/93_maplibre_pmtiles))
94. Creating 3D maps with Mapbox ([notebook](https://vgrid.org/notebooks/94_mapbox))
95. Editing vector data interactively ([notebook](https://vgrid.org/notebooks/95_edit_vector))
96. Batch editing vector data attributes interactively ([notebook](https://vgrid.org/notebooks/96_batch_edit_vector))
97. Downloading Overture Maps data ([notebook](https://vgrid.org/notebooks/97_overture_data))
98. Retrieving watershed boundaries from the National Hydrography Dataset (NHD) ([notebook](https://vgrid.org/notebooks/98_watershed))
99. Retrieving wetland boundaries from the National Wetlands Inventory (NWI) ([notebook](https://vgrid.org/notebooks/99_wetlands))
100. Visualizing the National Land Cover Database (NLCD) data products with vgrid ([notebook](https://vgrid.org/notebooks/100_nlcd))
101. Searching and Visualizing NASA OPERA Data Products Interactively ([notebook](https://vgrid.org/notebooks/101_nasa_opera))
102. Mapping Overture Buildings and Foursquare Places with vgrid + Fused ([notebook](https://vgrid.org/notebooks/102_fused))
103. Applying a custom colormap to a raster dataset ([notebook](https://vgrid.org/notebooks/103_raster_colormap))
104. Plotting point data with custom styles ([notebook](https://vgrid.org/notebooks/104_point_style))
105. Visualizing vector data with time attributes ([notebook](https://vgrid.org/notebooks/105_vector_time_slider))

## Demo

![](https://wetlands.io/file/images/vgrid_demo.gif)
